View Source PipeHelpers.Flow (PipeHelpers v1.5.2)
Link to this section Summary
Functions
If result is an error tuple, execute fun with the right part of result tuple as single argument
and return fun output.
Otherwise, return result as-is.
Link to this section Functions
If result is an error tuple, execute fun with the right part of result tuple as single argument
and return fun output.
Otherwise, return result as-is.